package com.fastbee.xunjian.mapper;

import com.fastbee.xunjian.domain.XjInspectionRoutes;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 巡检路线Mapper接口
 *
 * @author kenlixunjian
 * @date 2023-08-04
 */
@Mapper
public interface XjInspectionRoutesMapper {
    /**
     * 查询巡检路线
     *
     * @param id 巡检路线主键
     * @return 巡检路线
     */
    public XjInspectionRoutes selectXjInspectionRoutesById(Long id);

    /**
     * 查询巡检路线列表
     *
     * @param XjInspectionRoutes 巡检路线
     * @return 巡检路线集合
     */
    public List<XjInspectionRoutes> selectXjInspectionRoutesList(XjInspectionRoutes XjInspectionRoutes);

    /**
     * 新增巡检路线
     *
     * @param XjInspectionRoutes 巡检路线
     * @return 结果
     */
    public int insertXjInspectionRoutes(XjInspectionRoutes XjInspectionRoutes);

    /**
     * 修改巡检路线
     *
     * @param XjInspectionRoutes 巡检路线
     * @return 结果
     */
    public int updateXjInspectionRoutes(XjInspectionRoutes XjInspectionRoutes);

    /**
     * 删除巡检路线
     *
     * @param id 巡检路线主键
     * @return 结果
     */
    public int deleteXjInspectionRoutesById(Long id);

    /**
     * 批量删除巡检路线
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteXjInspectionRoutesByIds(Long[] ids);

    XjInspectionRoutes selectXjInspectionRoutesByName(@Param("name") String name);

    XjInspectionRoutes selectXjInspectionRoutesByQrSn(String qrSn);
}
